#
# spec file for package python-o2sclpy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname o2sclpy
%{?sle15_python_module_pythons}
Name:           python-o2sclpy
Version:        0.929
Release:        1.2
Summary:        Python extensions for O2scl
License:        GPL-3.0-only
URL:            https://neutronstars.utk.edu/code/o2sclpy
Source0:        https://files.pythonhosted.org/packages/source/o/o2sclpy/%{modname}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module matplotlib >= 3.1}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module yt}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION Tests
BuildRequires:  %{python_module scikit-learn}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  o2scl-devel >= %{version}
# /SECTION
Requires:       o2scl-devel >= %{version}
Requires:       python-h5py
Requires:       python-matplotlib >= 3.1
Requires:       python-numpy
Requires:       python-requests
Requires:       python-yt
Requires:       texlive-latex
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A high-level plotting script, o2graph, for quick matplotlib or yt plots for use
with the O2scl C++ library and a set of python classes for convenient plotting.

%prep
%setup -q -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/o2graph
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# TMPDIR with write permissions
export TMPDIR=`mktemp -d -p ./`
# test_interpm requires tensorflow, unavailable as package for oS
%pytest -k "not test_interpm"

%post
%python_install_alternative o2graph

%postun
%python_uninstall_alternative o2graph

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/o2graph
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}*.*-info/

%changelog
* Fri Jul 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.929:
  * No release notes.
- Switch to pyproject_* macros for builds (adds BuildRequires:
  python-pip and python-wheel).
- Add appropriate BuildRequires and run tests using pytest.
* Fri Jan 26 2024 Dirk Müller <dmueller@suse.com>
- update to 0.928:
  * Several improvements to documentation and examples.
  * Reworked interp_krige, interp_krige_optim, interpm_krige and
    interpm_krige_optim.
  * Fixed ioctl calls and removed default ncurses requirement.
  * Improved multiprecision support in the integrators and created
    funct_multip_transform. Created a getfp, setfp, sets_vec_vec,
    and setd_vec_vec functions for hdf_file.
  * Updated mcmc_para, eos_tov_interp, polylog, and eos_sn_hfsl
    classes.
  * Removed old acolm_o2graph functions.
  * Updated fermion_rel class, continuing work on multiprecision
    support.
  * Updated python interface for several classes.
  * Created new classes vec_prob_dens_mdim, vec_prob_cond_mdim,
    prob_dens_func_gmm,
  * Created new classes gmm_python, kde_python, interpm_python
    and reworked python support.
  * Created new FFT functions, rng_set_seed(), rng_set_seed_mpi(),
    screenify_trans(), backslashify(),
  * Created new example ex_tensor.
  * Created acol command to-hist for table3d objects,
    interp-table3d for table objects, to-gmm for table objects,
    refine for table3d and hist_2d objects. Improved commands
    generic, autocorr, to-gaussian.  Improved handling of string[]
    objects. Renamed entry to value and entry-grid to value-grid.
  * Work on experimental emulator classes and experimental exp_max.
  * Deprecated class interp, now superceded by interp_vec.
  * Generalized axpy_prod() for other linear algebra libraries.
  * Updated docker files, now including python support, tensorflow,
    and sckit-learn.
  * Fixed table::delete_column(), tensor_grid::copy_table3d_align(),
    tensor_grid::grid_rearrange_and_copy().
  * Created new unicode mode for format_float().
* Sun Aug 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.926:
  * No release notes.
- Bump requires o2scl-devel version (must be at least o2sclpy
  version).
- Add rpmlintrc file to suppress rpmlint errors about the
  o2scl-devel Requires.
- More file-grained file list to make sure egg-info carries the
  correct version number.
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Thu Dec 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.925
  * No release notes.
- Drop additional source file LICENSE as it is now included in
  o2sclpy source tarball.
- Improve package description.
- Bump o2scl-devel required version to 0.925.
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Jan  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
